interface CompilerHooks {
    onload?: (compiler: BaseCompiler) => Promise<any>;
    onInserted?: (data: any) => Promise<any>;
    onRemoved?: (data: any) => Promise<any>;
    onPrettier?: (data: string) => Promise<any>;
    onError?: (e: Error) => Promise<any>;
}
interface CompilerOptions {
    sourceCode: string;
    fileNameOrPath: string;
    hooks: CompilerHooks;
}
export declare enum CreateProperty {
    'State' = "State",
    'Function' = "Function"
}
export type CreatePropertyType = 'string' | 'number' | 'object' | 'boolean' | 'function' | 'array';
export interface CreatePropertyItem {
    type: CreatePropertyType;
    name: string;
    comment?: string;
    value?: any;
    params?: string[];
}
export interface CreatePropertyConfig {
    override?: boolean;
}
interface ParseFunctionResult {
    name: string;
    params: string[];
    body: string;
}
export interface BaseCompiler {
    code: string;
    getPrettierCode: () => Promise<string>;
    createProperty(type: CreateProperty | string, item: CreatePropertyItem, config?: CreatePropertyConfig): Promise<{
        type: CreateProperty | string;
        item: CreatePropertyItem;
        code: string;
    }>;
    deleteProperty(type: CreateProperty | string, name: string): Promise<boolean>;
    prettierCode(sourceCode: string): Promise<string>;
    parseFunction(code: string, functionName: string): Promise<ParseFunctionResult>;
    dispose: () => void;
    updateSourceCode: (code: string) => void;
    getDefaultValue: (variableType: CreatePropertyType) => any;
    getProperty(type: CreateProperty | string, name: string): Promise<CreatePropertyItem>;
}
declare const createCompilerFactory: (options: CompilerOptions) => Promise<BaseCompiler>;
export { createCompilerFactory };
